 .. Licensed to the Apache Software Foundation (ASF) under one
    or more contributor license agreements.  See the NOTICE file
    distributed with this work for additional information
    regarding copyright ownership.  The ASF licenses this file
    to you under the Apache License, Version 2.0 (the
    "License"); you may not use this file except in compliance
    with the License.  You may obtain a copy of the License at

 ..   http://www.apache.org/licenses/LICENSE-2.0

 .. Unless required by applicable law or agreed to in writing,
    software distributed under the License is distributed on an
    "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, either express or implied.  See the License for the
    specific language governing permissions and limitations
    under the License.

Microsoft WinRM Operators
=========================

use the WinRMOperator to execute commands on a given remote host using the winrm_hook

create a hook

.. exampleinclude:: /../tests/system/microsoft/winrm/example_winrm.py
    :language: python
    :dedent: 4
    :start-after: [START create_hook]
    :end-before: [END create_hook]

Run the operator, pass the hook, and pass a command to do something

.. exampleinclude:: /../tests/system/microsoft/winrm/example_winrm.py
    :language: python
    :dedent: 4
    :start-after: [START run_operator]
    :end-before: [END run_operator]
